@@ -24,7 +24,7 @@ def main():
     args = parser.parse_args()
     verbose = args.verbose
 
-    msg = "T %12s %s %s" % (
+    msg = "T %18s %s %s" % (
         locale.format("%d", get_total_size('.'), grouping=True),
         '',
         '.'
@@ -36,8 +36,13 @@ def main():
 def get_total_size(path):
     total = 0
     for root, dirs, files in os.walk(path):
-        subtotal = (sum(getsize(join(root, name)) for name in files))
-        total += subtotal
+        #subtotal = (sum(getsize(join(root, name)) for name in files))
+        for name in files:
+            try:
+                size = getsize(join(root, name))
+            except:
+                print("Can't read '%s' file" % join(root, name))
+            total += size
         #print("bytes in", root, subtotal)
     return total
 
@@ -57,7 +62,7 @@ def rec_tree_traverse(curr_dir, indent, verbose):
         if os.path.isfile(file_or_dir):
             files_subtotal += getsize(file_or_dir)
             if verbose == -1:
-                msg = "  %12s %s %s" % (
+                msg = "  %18s %s %s" % (
                     locale.format("%d", getsize(file_or_dir), grouping=True),
                     ' ' * indent,
                     file_or_dir
@@ -65,7 +70,7 @@ def rec_tree_traverse(curr_dir, indent, verbose):
                 print(msg)
 
     if verbose == -1:
-        msg = "  %12s %s %s" % (
+        msg = "  %18s %s %s" % (
             locale.format("%d", files_subtotal, grouping=True),
             ' ' * indent,
             curr_dir
@@ -74,7 +79,7 @@ def rec_tree_traverse(curr_dir, indent, verbose):
 
     for file_or_dir in dfList:
         if os.path.isdir(file_or_dir):
-            msg = "D %12s %s %s" % (
+            msg = "D %18s %s %s" % (
                 locale.format("%d",
                     get_total_size(file_or_dir), grouping=True),
                 ' ' * indent,
